@@ -6,7 +6,7 @@ Created on 27/06/2014
 import sys, types, inspect, functools
 from importlib import import_module
 
-__version__ = 1.4
+__version__ = 1.5
 
 class TypeCheckError(Exception): 
     pass
@@ -20,10 +20,15 @@ def _caller():
 
 NoType = object()
 NoneType = type(None)
+NotImplementedType = type(NotImplemented)
 
 def _resolve_type(obj):
     if obj is None:
         return NoneType
+    elif obj is NotImplemented:
+        return NotImplementedType
+    elif obj in (True, False):
+        return bool
     elif obj.__class__ is str and '.' in obj:
         pkg, cls = obj.rsplit('.', 1)
         return getattr(import_module(pkg), cls)
